# AF-Adapter (Attention-FFN Adapter): Enhanced Continual Pretraining

## Introduction

This repository contains the code for the paper [AF-Adapter: Enhanced Continual Pretraining for Building Chinese Biomedical Language Model](#).

## Installation

```bash
pip install af-adapter
```

## Usage

~~TODO~~

See [scipts](./scripts/) and [examples](./examples/) directory for more details.
